@@ -13,6 +13,7 @@
 #ifndef _UTIL_H
 #define _UTIL_H
 
+#include <inttypes.h>
 #include <stdbool.h>
 #include <time.h>
 #include <stdio.h>
@@ -20,7 +21,7 @@
 #define dprintf(X,Y) fprintf(stderr, (X), (Y))
 /* #define	dprintf(X, Y)  */
 
-#define LDNS_VERSION "1.3.0"
+#define LDNS_VERSION "1.5.1"
 
 /**
  * splint static inline workaround
@@ -277,4 +278,14 @@ time_t mktime_from_utc(const struct tm *tm);
  */
 int ldns_init_random(FILE *fd, unsigned int size);
 
+
+/**
+ * Encode data as BubbleBabble
+ *
+ * \param[in] data a pointer to data to be encoded
+ * \param[in] len size the number of bytes of data
+ * \return a string of BubbleBabble
+ */
+char *ldns_bubblebabble(uint8_t *data, size_t len);
+
 #endif /* !_UTIL_H */
